@@ -484,16 +484,19 @@ impl StateHub {
         wait: bool,
     ) -> anyhow::Result<()> {
         let missing_locations = self.get_missing_locations(states, locations).await?;
-        let multiple_missing_locations = missing_locations
-            .iter()
-            .filter(|(_, locations)| locations.len() > 1)
-            .map(|(state, locations)| (state.clone(), locations.clone()))
-            .collect::<IndexMap<_, _>>();
 
-        if !wait && !multiple_missing_locations.is_empty() {
-            let add_locations = generate_add_location_commands(&missing_locations).join("\n");
-            let text = format!(
-                r#"Some states will need multiple locations to be added
+        if !wait {
+            let not_ready_states_with_missing_locations = missing_locations
+                .iter()
+                .any(|(state, locations)| !state.is_ready() && !locations.is_empty());
+            let multiple_missing_locations = missing_locations
+                .iter()
+                .any(|(_, locations)| locations.len() > 1);
+
+            if not_ready_states_with_missing_locations || multiple_missing_locations {
+                let add_locations = generate_add_location_commands(&missing_locations).join("\n");
+                let text = format!(
+                    r#"Some states will need multiple locations to be added
 and it is not possible at the moment without '--wait' flag.
 
 You can either re-run this command with '--wait' flag
@@ -501,9 +504,10 @@ or run following commands before running 'statehub register-cluster`
 
 {}
 "#,
-                add_locations
-            );
-            anyhow::bail!(text)
+                    add_locations
+                );
+                anyhow::bail!(text)
+            }
         }
 
         for (state, locations) in &missing_locations {
